@@ -4,6 +4,15 @@ Util functions
 
 const flatMap = (xs) => xs.reduce((x,y ) => x.concat(y), []); // Not all browsers have Array.flatMap
 
+/*
+* Equivalent of Python zip(*args) function. Usage:
+*
+* for (let [var1, ..., varN] of zip(arr1, ..., arrN)) {
+*   ...
+* }
+*/
+const zip = (...arrays) => [...arrays[0]].map((_,index) => arrays.map(arr => arr[index]))
+
 const doesFileExist = async (path) => {
     return await eel.does_file_exist(path)();
 };
